#[repr(transparent)]pub struct SessionSecurity {
inner: TypedObjectRef<SessionSecurity, ()>,
phantom: PhantomData<()>,
}Expand description
Information about the security of a Matrix session.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<SessionSecurity, ()>phantom: PhantomData<()>Implementations
Sourceimpl SessionSecurity
impl SessionSecurity
Sourcepub fn set_session<'a>(
&self,
value: Option<impl Borrow<<<WeakRef<Session> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_session<'a>( &self, value: Option<impl Borrow<<<WeakRef<Session> as Property>::Value as HasParamSpec>::SetValue>>, )
The current session.
Sourcepub fn crypto_identity_state(
&self,
) -> <Cell<CryptoIdentityState> as Property>::Value
pub fn crypto_identity_state( &self, ) -> <Cell<CryptoIdentityState> as Property>::Value
The state of the crypto identity for the current session.
Sourcepub fn verification_state(
&self,
) -> <Cell<SessionVerificationState> as Property>::Value
pub fn verification_state( &self, ) -> <Cell<SessionVerificationState> as Property>::Value
The state of the verification for the current session.
Sourcepub fn recovery_state(&self) -> <Cell<RecoveryState> as Property>::Value
pub fn recovery_state(&self) -> <Cell<RecoveryState> as Property>::Value
The state of recovery for the current session.
Sourcepub fn cross_signing_keys_available(&self) -> <Cell<bool> as Property>::Value
pub fn cross_signing_keys_available(&self) -> <Cell<bool> as Property>::Value
Whether all the cross-signing keys are available.
Sourcepub fn backup_enabled(&self) -> <Cell<bool> as Property>::Value
pub fn backup_enabled(&self) -> <Cell<bool> as Property>::Value
Whether the room keys backup is enabled.
Sourcepub fn backup_exists_on_server(&self) -> <Cell<bool> as Property>::Value
pub fn backup_exists_on_server(&self) -> <Cell<bool> as Property>::Value
Whether the room keys backup exists on the homeserver.
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_crypto_identity_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_crypto_identity_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the crypto-identity-state property
Sourcepub fn connect_verification_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_verification_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the verification-state property
Sourcepub fn connect_recovery_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_recovery_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the recovery-state property
Sourcepub fn connect_cross_signing_keys_available_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_cross_signing_keys_available_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the cross-signing-keys-available property
Sourcepub fn connect_backup_enabled_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_backup_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the backup-enabled property
Sourcepub fn connect_backup_exists_on_server_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_backup_exists_on_server_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the backup-exists-on-server property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_crypto_identity_state(&self)
pub fn notify_crypto_identity_state(&self)
Notify listeners of a change in the crypto-identity-state property
Sourcepub fn notify_verification_state(&self)
pub fn notify_verification_state(&self)
Notify listeners of a change in the verification-state property
Sourcepub fn notify_recovery_state(&self)
pub fn notify_recovery_state(&self)
Notify listeners of a change in the recovery-state property
Sourcepub fn notify_cross_signing_keys_available(&self)
pub fn notify_cross_signing_keys_available(&self)
Notify listeners of a change in the cross-signing-keys-available property
Sourcepub fn notify_backup_enabled(&self)
pub fn notify_backup_enabled(&self)
Notify listeners of a change in the backup-enabled property
Sourcepub fn notify_backup_exists_on_server(&self)
pub fn notify_backup_exists_on_server(&self)
Notify listeners of a change in the backup-exists-on-server property